@@ -1,4 +1,4 @@
-from typing import Optional, TypeVar, Union
+from typing import List, Optional, TypeVar, Union
 
 from pyspark.sql import DataFrame, Column
 
@@ -16,6 +16,15 @@ _TAutoMapperDataType = TypeVar(
 class AutoMapperArrayLikeBase(AutoMapperTextLikeBase):
     # noinspection PyMethodMayBeStatic
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         raise NotImplementedError  # base classes should implement this
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return []
