@@ -1,5 +1,5 @@
 import re
-from typing import Optional, List
+from typing import List, Optional, Union
 
 from pyspark.sql import Column, DataFrame
 
@@ -7,6 +7,7 @@ from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
+from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
 
 
 class AutoMapperDataTypeColumn(AutoMapperArrayLikeBase):
@@ -18,7 +19,10 @@ class AutoMapperDataTypeColumn(AutoMapperArrayLikeBase):
             self.value = value
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         if isinstance(self.value, str):
             if not self.value.startswith("a.") and not self.value.startswith("b."):
@@ -40,3 +44,9 @@ class AutoMapperDataTypeColumn(AutoMapperArrayLikeBase):
                 return col(self.value)
 
         raise ValueError(f"value: {self.value} is not str")
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return []
