@@ -1,4 +1,4 @@
-from typing import Optional, List, Union
+from typing import List, Optional, Union
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import coalesce, to_date
@@ -36,13 +36,18 @@ class AutoMapperDateDataType(AutoMapperDataTypeBase):
         self.formats: Optional[List[str]] = formats
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         formats_column_specs: List[Column] = (
             [
                 to_date(
                     self.value.get_column_spec(
-                        source_df=source_df, current_column=current_column
+                        source_df=source_df,
+                        current_column=current_column,
+                        parent_columns=parent_columns,
                     ),
                     format=format_,
                 )
@@ -52,19 +57,25 @@ class AutoMapperDateDataType(AutoMapperDataTypeBase):
             else [
                 to_date(
                     self.value.get_column_spec(
-                        source_df=source_df, current_column=current_column
+                        source_df=source_df,
+                        current_column=current_column,
+                        parent_columns=parent_columns,
                     ),
                     format="y-M-d",
                 ),
                 to_date(
                     self.value.get_column_spec(
-                        source_df=source_df, current_column=current_column
+                        source_df=source_df,
+                        current_column=current_column,
+                        parent_columns=parent_columns,
                     ),
                     format="yyyyMMdd",
                 ),
                 to_date(
                     self.value.get_column_spec(
-                        source_df=source_df, current_column=current_column
+                        source_df=source_df,
+                        current_column=current_column,
+                        parent_columns=parent_columns,
                     ),
                     format="M/d/y",
                 ),
@@ -85,7 +96,9 @@ class AutoMapperDateDataType(AutoMapperDataTypeBase):
             return coalesce(*formats_column_specs)
         else:
             column_spec = self.value.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             )
             return column_spec
 
