@@ -1,4 +1,4 @@
-from typing import Generic, Optional, TypeVar, Union
+from typing import Generic, List, Optional, TypeVar, Union
 
 from pyspark.sql import DataFrame, Column
 
@@ -23,10 +23,21 @@ class AutoMapperFirstDataType(AutoMapperArrayLikeBase, Generic[_TAutoMapperDataT
         ] = column
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         column_spec: Column = self.column.get_column_spec(
-            source_df=source_df, current_column=current_column
+            source_df=source_df,
+            current_column=current_column,
+            parent_columns=parent_columns,
         )
 
         return column_spec[0]
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.column
