@@ -1,4 +1,4 @@
-from typing import Union, List, Optional, Generic, TypeVar
+from typing import Generic, List, Optional, TypeVar, Union
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import array, coalesce
@@ -86,7 +86,10 @@ class AutoMapperList(AutoMapperArrayLikeBase, Generic[_T]):
             )
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         """
         returns a Spark Column definition
@@ -105,9 +108,13 @@ class AutoMapperList(AutoMapperArrayLikeBase, Generic[_T]):
             inner_array = array(
                 *[
                     self.get_value(
-                        item, source_df=source_df, current_column=current_column
+                        item,
+                        source_df=source_df,
+                        current_column=current_column,
+                        parent_columns=parent_columns,
                     )
                     for item in self.value
+                    if item is not None
                 ]
             )
             return (
@@ -127,7 +134,9 @@ class AutoMapperList(AutoMapperArrayLikeBase, Generic[_T]):
         if isinstance(self.value, AutoMapperDataTypeBase):
             child: AutoMapperDataTypeBase = self.value
             inner_child_spec = child.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             )
             return (
                 when(
