@@ -1,4 +1,4 @@
-from typing import Optional, List, Union
+from typing import List, Optional, Union
 
 from pyspark.sql import DataFrame, Column
 from pyspark.sql.functions import lpad
@@ -24,11 +24,16 @@ class AutoMapperLPadDataType(AutoMapperTextLikeBase):
         self.pad: str = pad
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         column_spec = lpad(
             col=self.column.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             ),
             len=self.length,
             pad=self.pad,
