@@ -13,6 +13,7 @@ from spark_auto_mapper.data_types.complex.complex_base import (
 from spark_auto_mapper.data_types.number import AutoMapperNumberDataType
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 class MyClass(AutoMapperDataTypeComplexBase):
@@ -64,10 +65,12 @@ def test_auto_mapper_complex_with_defined_class(spark_session: SparkSession) ->
     result_df: DataFrame = mapper.transform(df=df)
 
     # Assert
-    assert str(sql_expressions["name"]) == str(
-        col("b.last_name").cast("string").alias("name")
+    assert_compare_expressions(
+        sql_expressions["name"], col("b.last_name").cast("string").alias("name")
+    )
+    assert_compare_expressions(
+        sql_expressions["age"], col("b.my_age").cast("long").alias("age")
     )
-    assert str(sql_expressions["age"]) == str(col("b.my_age").cast("long").alias("age"))
 
     result_df.printSchema()
     result_df.show()
