@@ -23,6 +23,7 @@ from spark_auto_mapper.data_types.list import AutoMapperList
 from spark_auto_mapper.data_types.number import AutoMapperNumberDataType
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 from spark_auto_mapper.type_definitions.defined_types import AutoMapperDateInputType
 
 
@@ -101,8 +102,9 @@ class MyProcessingStatusExtension(AutoMapperDataTypeComplexBase):
         value: AutoMapperDataTypeBase,
         source_df: Optional[DataFrame],
         current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
-        return super().get_value(value, source_df, current_column)
+        return super().get_value(value, source_df, current_column, parent_columns)
 
 
 class MyClass(AutoMapperDataTypeComplexBase):
@@ -171,10 +173,12 @@ def test_auto_mapper_complex_with_extension(spark_session: SparkSession) -> None
     result_df: DataFrame = mapper.transform(df=df)
 
     # Assert
-    assert str(sql_expressions["name"]) == str(
-        col("b.last_name").cast("string").alias("name")
+    assert_compare_expressions(
+        sql_expressions["name"], col("b.last_name").cast("string").alias("name")
+    )
+    assert_compare_expressions(
+        sql_expressions["age"], col("b.my_age").cast("long").alias("age")
     )
-    assert str(sql_expressions["age"]) == str(col("b.my_age").cast("long").alias("age"))
 
     result_df.printSchema()
     result_df.show(truncate=False)
