@@ -19,12 +19,15 @@ from spark_auto_mapper.data_types.complex.complex_base import (
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
+from tests.conftest import clean_spark_session
 
 
 def test_auto_mapper_concat_multiple_items_structs_different_elements(
     spark_session: SparkSession,
 ) -> None:
     # Arrange
+    clean_spark_session(spark_session)
     spark_session.createDataFrame(
         [
             (1, "Qureshi", "Imran"),
@@ -35,15 +38,9 @@ def test_auto_mapper_concat_multiple_items_structs_different_elements(
 
     source_df: DataFrame = spark_session.table("patients")
 
-    df: DataFrame = source_df.select("member_id")
-    df.createOrReplaceTempView("members")
-
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"],
-        drop_key_columns=False,
+        view="members", source_view="patients", enable_schema_pruning=True
     ).columns(
         dst2=AutoMapperList(
             [
@@ -111,9 +108,11 @@ def test_auto_mapper_concat_multiple_items_structs_different_elements(
             lambda x: x.isNotNull(),
         ),
     )
-    assert str(sql_expressions["dst2"]) == str(concat(array1, array2).alias("dst2"))
+    assert_compare_expressions(
+        sql_expressions["dst2"], concat(array1, array2).alias("dst2")
+    )
 
-    result_df: DataFrame = mapper.transform(df=df)
+    result_df: DataFrame = mapper.transform(df=source_df)
 
     # Assert
     result_df.printSchema()
