@@ -9,6 +9,7 @@ from pyspark.sql.types import StringType, LongType
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_automapper_if_list(spark_session: SparkSession) -> None:
@@ -44,10 +45,11 @@ def test_automapper_if_list(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(
+    assert_compare_expressions(
+        sql_expressions["age"],
         when(col("b.my_age").isin(["54", "59"]), col("b.my_age").cast("long"))
         .otherwise(lit("100").cast(StringType()).cast(LongType()))
-        .alias("age")
+        .alias("age"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
