@@ -8,8 +8,8 @@ from pyspark.sql.functions import lit
 from pyspark.sql.types import StringType, LongType
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_automapper_if_regex(spark_session: SparkSession) -> None:
@@ -44,7 +44,7 @@ def test_automapper_if_regex(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
+    assert_compare_expressions(
         sql_expressions["age"],
         when(col("b.my_age").rlike("5*"), col("b.my_age").cast(LongType()))
         .otherwise(lit("100").cast(StringType()).cast(LongType()))
