@@ -6,6 +6,7 @@ from pyspark.sql.functions import lit, filter
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
@@ -36,14 +37,15 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["dst2"]) == str(
+    assert_compare_expressions(
+        sql_expressions["dst2"],
         when(
             array(lit("address1"), lit("address2")).isNotNull(),
             filter(
                 coalesce(array(lit("address1"), lit("address2")), array()),
                 lambda x: x.isNotNull(),
             ),
-        ).alias("dst2")
+        ).alias("dst2"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
