@@ -5,6 +5,7 @@ from pyspark.sql.functions import array, expr, filter, when, coalesce
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
@@ -35,11 +36,12 @@ def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["dst2"]) == str(
+    assert_compare_expressions(
+        sql_expressions["dst2"],
         when(
             array(expr("address1")).isNotNull(),
             filter(coalesce(array(expr("address1")), array()), lambda x: x.isNotNull()),
-        ).alias("dst2")
+        ).alias("dst2"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
