@@ -6,8 +6,8 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
@@ -35,7 +35,7 @@ def test_auto_mapper_with_column(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
+    assert_compare_expressions(
         sql_expressions["lname"], col("b.last_name").alias("lname")
     )
 
