@@ -7,6 +7,7 @@ from pyspark.sql.functions import expr
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_with_column_expression(spark_session: SparkSession) -> None:
@@ -34,8 +35,8 @@ def test_auto_mapper_with_column_expression(spark_session: SparkSession) -> None
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["lname"]) == str(
-        expr("SUBSTRING(last_name,1,3)").alias("lname")
+    assert_compare_expressions(
+        sql_expressions["lname"], expr("SUBSTRING(last_name,1,3)").alias("lname")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
